# Neutrino Propagator


-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install nupropagator
```

## License

`nupropagator` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
